@@ -1144,7 +1144,7 @@ ConsoleReaderThread(
 {
     ConsoleInfo *infoPtr = (ConsoleInfo *)arg;
     HANDLE *handle = infoPtr->handle;
-    DWORD count, waitResult;
+    DWORD waitResult;
     HANDLE wEvents[2];
 
     /* The first event takes precedence. */
@@ -1167,8 +1167,6 @@ ConsoleReaderThread(
 	    break;
 	}
 
-	count = 0;
-
 	/*
 	 * Look for data on the console, but first ignore any events that are
 	 * not KEY_EVENTs.
@@ -1364,7 +1362,7 @@ TclWinOpenConsoleChannel(
      * for instance).
      */
 
-    wsprintfA(channelName, "file%lx", (int) infoPtr);
+    sprintf(channelName, "file%" TCL_I_MODIFIER "x", (size_t)infoPtr);
 
     infoPtr->channel = Tcl_CreateChannel(&consoleChannelType, channelName,
 	    (ClientData) infoPtr, permissions);
